/*
 *  Copyright (C) 2014 Steve Harris et al. (see AUTHORS)
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public License
 *  as published by the Free Software Foundation; either version 2.1
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  $Id$
 */

#ifndef LO_ERRORS_H
#define LO_ERRORS_H

#ifdef __cplusplus
extern "C" {
#endif

#define LO_ENOPATH      9901
#define LO_ENOTYPE      9902
#define LO_UNKNOWNPROTO 9903
#define LO_NOPORT       9904
#define LO_TOOBIG       9905
#define LO_INT_ERR      9906
#define LO_EALLOC       9907
#define LO_EINVALIDPATH 9908
#define LO_EINVALIDTYPE 9909
#define LO_EBADTYPE     9910
#define LO_ESIZE        9911
#define LO_EINVALIDARG  9912
#define LO_ETERM        9913
#define LO_EPAD         9914
#define LO_EINVALIDBUND 9915
#define LO_EINVALIDTIME 9916

#ifdef __cplusplus
}
#endif

#endif
